
from django.contrib.auth.models import User, Group
from django.urls import reverse
from django.test import RequestFactory, TestCase
from rest_framework.test import APIClient
from uhepp_vault.models import Collection, Plot

class RootEndpointTestCase(TestCase):
    """Test the api-root endpoint"""

    fixtures = ["users.json"]

    def setUp(self):
        self.client = APIClient()

        self.frank = User.objects.get(username="cern-fsauerbu")

    def test_users_anon(self):
        """Check that users endpoint is presented for anonymous users"""
        response = self.client.get(reverse("api-root"))
        self.assertIn("users", response.json())
        
    def test_users_auth(self):
        """Check that users endpoint is presented for authenticated users"""
        self.client.force_authenticate(self.frank)
        response = self.client.get(reverse("api-root"))
        self.assertIn("users", response.json())

    def test_collections_anon(self):
        """Check that /collections is presented for anonymous users"""
        response = self.client.get(reverse("api-root"))
        self.assertIn("collections", response.json())
        
    def test_collections_auth(self):
        """Check that /collections is presented for authenticated users"""
        self.client.force_authenticate(self.frank)
        response = self.client.get(reverse("api-root"))
        self.assertIn("collections", response.json())

    def test_plots_anon(self):
        """Check that /plots is presented for anonymous users"""
        response = self.client.get(reverse("api-root"))
        self.assertIn("plots", response.json())
        
    def test_plots_auth(self):
        """Check that /plots is presented for authenticated users"""
        self.client.force_authenticate(self.frank)
        response = self.client.get(reverse("api-root"))
        self.assertIn("plots", response.json())
        
